@@ -68,6 +68,7 @@ import org.apache.http.NameValuePair;
 import org.apache.http.StatusLine;
 import org.apache.http.auth.AuthenticationException;
 import org.apache.http.client.ClientProtocolException;
+import org.apache.http.client.HttpClient;
 import org.apache.http.client.HttpResponseException;
 import org.apache.http.client.methods.HttpPost;
 import org.apache.http.client.methods.HttpRequestBase;
@@ -76,7 +77,6 @@ import org.apache.http.client.utils.URLEncodedUtils;
 import org.apache.http.entity.ContentType;
 import org.apache.http.entity.InputStreamEntity;
 import org.apache.http.impl.auth.BasicScheme;
-import org.apache.http.impl.client.CloseableHttpClient;
 import org.apache.http.message.BasicNameValuePair;
 import org.apache.http.protocol.BasicHttpContext;
 import org.json.JSONException;
@@ -465,7 +465,7 @@ public class WeakforcedClient implements AntiAbuseService {
      * @throws ClientProtocolException If client protocol error occurs
      * @throws IOException If an I/O error occurs
      */
-    protected HttpResponse execute(HttpRequestBase method, HttpHost targetHost, CloseableHttpClient httpClient) throws ClientProtocolException, IOException {
+    protected HttpResponse execute(HttpRequestBase method, HttpHost targetHost, HttpClient httpClient) throws ClientProtocolException, IOException {
         return execute(method, targetHost, httpClient, localcontext);
     }
 
@@ -480,7 +480,7 @@ public class WeakforcedClient implements AntiAbuseService {
      * @throws ClientProtocolException If client protocol error occurs
      * @throws IOException If an I/O error occurs
      */
-    protected HttpResponse execute(HttpRequestBase method, HttpHost targetHost, CloseableHttpClient httpClient, BasicHttpContext context) throws ClientProtocolException, IOException {
+    protected HttpResponse execute(HttpRequestBase method, HttpHost targetHost, HttpClient httpClient, BasicHttpContext context) throws ClientProtocolException, IOException {
         return httpClient.execute(targetHost, method, context);
     }
 
@@ -672,10 +672,10 @@ public class WeakforcedClient implements AntiAbuseService {
 
         final URI uri;
         final HttpHost targetHost;
-        final CloseableHttpClient httpClient;
+        final HttpClient httpClient;
         final Endpoint endpoint;
 
-        CallProperties(URI uri, CloseableHttpClient httpClient, HttpHost targetHost, Endpoint endpoint) {
+        CallProperties(URI uri, HttpClient httpClient, HttpHost targetHost, Endpoint endpoint) {
             super();
             this.uri = uri;
             this.httpClient = httpClient;
