@@ -53,6 +53,7 @@ import java.util.LinkedHashMap;
 import java.util.Map;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.locks.LockSupport;
+import com.openexchange.ajax.Client;
 import com.openexchange.antiabuse.AllowParameters;
 import com.openexchange.antiabuse.AntiAbuseService;
 import com.openexchange.antiabuse.Protocol;
@@ -60,6 +61,7 @@ import com.openexchange.antiabuse.ReportParameters;
 import com.openexchange.antiabuse.ReportValue;
 import com.openexchange.antiabuse.Status;
 import com.openexchange.authentication.LoginExceptionCodes;
+import com.openexchange.config.ConfigurationService;
 import com.openexchange.exception.OXException;
 import com.openexchange.java.Strings;
 import com.openexchange.login.LoginRequest;
@@ -79,12 +81,14 @@ public class WeakforcedLoginListener implements LoginListener {
 
     private final AntiAbuseService weakforcedClient;
     private final String[] attributeNames;
+    private final ConfigurationService configurationService;
 
     /**
      * Initializes a new {@link WeakforcedLoginListener}.
      */
-    public WeakforcedLoginListener(AntiAbuseService weakforcedClient, String[] attributeNames) {
+    public WeakforcedLoginListener(ConfigurationService configurationService, AntiAbuseService weakforcedClient, String[] attributeNames) {
         super();
+        this.configurationService = configurationService;
         this.weakforcedClient = weakforcedClient;
         this.attributeNames = attributeNames;
     }
@@ -118,6 +122,17 @@ public class WeakforcedLoginListener implements LoginListener {
             performReportSafe(ReportValue.DENIED_BY_SERVICE, login, password, remoteAddress, userAgent, protocol);
 
             // Throw exception since Weakforced denied login
+            boolean showErrorMessage = this.configurationService.getBoolProperty(WeakforcedProperties.INCLUDE_ERROR, true);
+            if (showErrorMessage) {
+                String message = status.getMessage();
+                String messageSuffix = this.configurationService.getProperty(WeakforcedProperties.ERROR_SUFFIX);
+                if (Strings.isNotEmpty(messageSuffix)) {
+                    message = Strings.isNotEmpty(message) ? (message + " " + messageSuffix) : messageSuffix;
+                }
+                if (Strings.isNotEmpty(message)) {
+                    throw LoginExceptionCodes.LOGIN_DENIED_WITH_MESSAGE.create(message);
+                }
+            }
             throw LoginExceptionCodes.LOGIN_DENIED.create();
         }
         int waitSeconds = status.getWaitSeconds();
@@ -126,8 +141,18 @@ public class WeakforcedLoginListener implements LoginListener {
         }
     }
 
-    private boolean isAnonymous(String login, String password) {
-        return Strings.isEmpty(login) || Strings.isEmpty(password);
+    private boolean isAnonymous(String login) {
+        return Strings.isEmpty(login);
+    }
+
+    private Protocol protocolFor(LoginRequest request) {
+        String client = request.getClient();
+        if (client != null && Strings.asciiLowerCase(client).startsWith(Client.MOBILE_API_FACADE.getClientId())) {
+            return Protocol.newInstance("mobileapi", request.isSecure());
+        }
+
+        // Otherwise assume "http"
+        return request.isSecure() ? Protocol.HTTPS : Protocol.HTTP;
     }
 
     private Status performAllowSafe(String login, String password, String remoteAddress, Map<String, String> attributes, String userAgent, Protocol protocol) {
@@ -163,16 +188,25 @@ public class WeakforcedLoginListener implements LoginListener {
         }
     }
 
+    private String getPassword(LoginRequest request) {
+        String password = request.getPassword();
+        if (Strings.isEmpty(password)) {
+            password = "0000";
+        }
+        return password;
+    }
+
     @Override
     public void onBeforeAuthentication(LoginRequest request, Map<String, Object> properties) throws OXException {
         String login = request.getLogin();
-        String password = request.getPassword();
-        String userAgent = request.getUserAgent();
-        Protocol protocol = request.isSecure() ? Protocol.HTTPS : Protocol.HTTP;
-
-        if (isAnonymous(login, password)) {
+        if (isAnonymous(login)) {
+            LOGGER.debug("Denying 'allow' request to Weakforced end-point since login is absent or empty");
             return;
         }
+
+        String password = getPassword(request);
+        String userAgent = request.getUserAgent();
+        Protocol protocol =  protocolFor(request);
         String remoteAddress = request.getClientIP();
 
         Map<String, String> attributes = null;
@@ -190,10 +224,15 @@ public class WeakforcedLoginListener implements LoginListener {
     public void onSucceededAuthentication(LoginResult result) throws OXException {
         LoginRequest request = result.getRequest();
         String login = request.getLogin();
-        String password = request.getPassword();
+        if (isAnonymous(login)) {
+            LOGGER.debug("Denying 'report' request to Weakforced end-point on succeeded authentication since login is absent or empty");
+            return;
+        }
+
+        String password = getPassword(request);
         String remoteAddress = request.getClientIP();
         String userAgent = request.getUserAgent();
-        Protocol protocol = request.isSecure() ? Protocol.HTTPS : Protocol.HTTP;
+        Protocol protocol = protocolFor(request);
 
         // The post-authentication 'allow' hook is to enable the client to send data to weakforced from the provisioning system (e.g. LDAP)
         {
@@ -236,10 +275,15 @@ public class WeakforcedLoginListener implements LoginListener {
         }
 
         String login = request.getLogin();
-        String password = request.getPassword();
+        if (isAnonymous(login)) {
+            LOGGER.debug("Denying 'report' request to Weakforced end-point on failed authentication since login is absent or empty");
+            return;
+        }
+
+        String password = getPassword(request);
         String remoteAddress = request.getClientIP();
         String userAgent = request.getUserAgent();
-        Protocol protocol = request.isSecure() ? Protocol.HTTPS : Protocol.HTTP;
+        Protocol protocol = protocolFor(request);
 
         // Do the report
         performReportSafe(ReportValue.FAILURE, login, password, remoteAddress, userAgent, protocol);
