@@ -49,6 +49,7 @@
 
 package com.openexchange.weakforced.osgi;
 
+import java.util.List;
 import com.openexchange.antiabuse.AntiAbuseService;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.exception.OXException;
@@ -56,10 +57,14 @@ import com.openexchange.java.Strings;
 import com.openexchange.login.listener.LoginListener;
 import com.openexchange.osgi.HousekeepingActivator;
 import com.openexchange.rest.client.endpointpool.EndpointManagerFactory;
+import com.openexchange.rest.client.httpclient.HttpClientService;
+import com.openexchange.rest.client.httpclient.SpecificHttpClientConfigProvider;
 import com.openexchange.timer.TimerService;
+import com.openexchange.version.VersionService;
 import com.openexchange.weakforced.WeakforcedClient;
 import com.openexchange.weakforced.WeakforcedEndpointManager;
 import com.openexchange.weakforced.WeakforcedLoginListener;
+import com.openexchange.weakforced.WeakforcedProperties;
 
 
 /**
@@ -70,7 +75,7 @@ import com.openexchange.weakforced.WeakforcedLoginListener;
  */
 public class WeakforcedActivator extends HousekeepingActivator {
 
-    private volatile WeakforcedEndpointManager endpointManager;
+    private WeakforcedEndpointManager endpointManager;
 
     /**
      * Initializes a new {@link WeakforcedActivator}.
@@ -81,37 +86,43 @@ public class WeakforcedActivator extends HousekeepingActivator {
 
     @Override
     protected Class<?>[] getNeededServices() {
-        return new Class<?>[] { ConfigurationService.class, EndpointManagerFactory.class, TimerService.class };
+        return new Class<?>[] { ConfigurationService.class, EndpointManagerFactory.class, TimerService.class, VersionService.class };
     }
 
     @Override
-    protected void startBundle() throws Exception {
+    protected synchronized void startBundle() throws Exception {
         org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(WeakforcedActivator.class);
 
+        trackService(HttpClientService.class);
+        openTrackers();
+
         ConfigurationService configService = getService(ConfigurationService.class);
 
-        String secret = configService.getProperty("com.openexchange.weakforced.hash.secret");
+        String secret = configService.getProperty(WeakforcedProperties.HASH_SECRET);
         if (Strings.isEmpty(secret)) {
             throw OXException.general("Denied initialization due to unset secret configuration. Please specify property 'com.openexchange.weakforced.hash.secret'.");
         }
 
-        String algorithm = configService.getProperty("com.openexchange.weakforced.hash.algorithm");
+        String algorithm = configService.getProperty(WeakforcedProperties.HASH_ALGORITHM);
         if (Strings.isEmpty(secret)) {
             algorithm = "SHA-256";
         } else {
             algorithm = Strings.toUpperCase(algorithm.trim());
         }
 
-        boolean truncate = configService.getBoolProperty("com.openexchange.weakforced.hash.truncate", true);
+        boolean truncate = configService.getBoolProperty(WeakforcedProperties.HASH_TRUNCATE, true);
 
         EndpointManagerFactory factory = getService(EndpointManagerFactory.class);
-        WeakforcedEndpointManager endpointManager = new WeakforcedEndpointManager();
-        endpointManager.init(factory, configService);
+        WeakforcedEndpointManager endpointManager = new WeakforcedEndpointManager(this);
+        List<SpecificHttpClientConfigProvider> configProviders = endpointManager.init(factory, this);
+        for (SpecificHttpClientConfigProvider configProvider : configProviders) {
+            registerService(SpecificHttpClientConfigProvider.class, configProvider);
+        }
         this.endpointManager = endpointManager;
 
         String[] attributeNames;
         {
-            String sAttributes = configService.getProperty("com.openexchange.weakforced.attributes");
+            String sAttributes = configService.getProperty(WeakforcedProperties.ATTRIBUTES);
             if (Strings.isEmpty(sAttributes)) {
                 attributeNames = null;
             } else {
@@ -122,12 +133,12 @@ public class WeakforcedActivator extends HousekeepingActivator {
         WeakforcedClient weakforcedClient = new WeakforcedClient(endpointManager, secret, algorithm, truncate);
         registerService(AntiAbuseService.class, weakforcedClient);
 
-        registerService(LoginListener.class, new WeakforcedLoginListener(weakforcedClient, attributeNames));
+        registerService(LoginListener.class, new WeakforcedLoginListener(configService, weakforcedClient, attributeNames));
         logger.info("Started bundle: {}", context.getBundle().getSymbolicName());
     }
 
     @Override
-    protected void stopBundle() throws Exception {
+    protected synchronized void stopBundle() throws Exception {
         WeakforcedEndpointManager endpointManager = this.endpointManager;
         if (null != endpointManager) {
             this.endpointManager = null;
@@ -135,7 +146,6 @@ public class WeakforcedActivator extends HousekeepingActivator {
         }
         super.stopBundle();
 
-
         org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(WeakforcedActivator.class);
         logger.info("Stopped bundle: {}", context.getBundle().getSymbolicName());
     }
